@@ -1,12 +1,11 @@
 # ruff: noqa: TC004
 """Common base classes for SQLAlchemy declarative models."""
 
-from __future__ import annotations
-
 import contextlib
 import datetime
 import re
-from typing import TYPE_CHECKING, Any, Iterator, Optional, Protocol, cast, runtime_checkable
+from collections.abc import Iterator
+from typing import TYPE_CHECKING, Any, Optional, Protocol, Union, cast, runtime_checkable
 from uuid import UUID
 
 from sqlalchemy import Date, MetaData, String
@@ -19,79 +18,56 @@ from sqlalchemy.orm import (
 from sqlalchemy.orm import (
     registry as SQLAlchemyRegistry,  # noqa: N812
 )
-from sqlalchemy.orm.decl_base import _TableArgsType as TableArgsType  # pyright: ignore[reportPrivateUsage]
+from sqlalchemy.orm.decl_base import (
+    _TableArgsType as TableArgsType,  # pyright: ignore[reportPrivateUsage]
+)
+from sqlalchemy.types import TypeEngine
 from typing_extensions import Self, TypeVar
 
 from advanced_alchemy.mixins import (
-    AuditColumns as _AuditColumns,
+    AuditColumns,
+    BigIntPrimaryKey,
+    IdentityPrimaryKey,
+    NanoIDPrimaryKey,
+    UUIDPrimaryKey,
+    UUIDv6PrimaryKey,
+    UUIDv7PrimaryKey,
 )
-from advanced_alchemy.mixins import (
-    BigIntPrimaryKey as _BigIntPrimaryKey,
-)
-from advanced_alchemy.mixins import (
-    NanoIDPrimaryKey as _NanoIDPrimaryKey,
-)
-from advanced_alchemy.mixins import (
-    UUIDPrimaryKey as _UUIDPrimaryKey,
-)
-from advanced_alchemy.mixins import (
-    UUIDv6PrimaryKey as _UUIDv6PrimaryKey,
-)
-from advanced_alchemy.mixins import (
-    UUIDv7PrimaryKey as _UUIDv7PrimaryKey,
-)
-from advanced_alchemy.types import GUID, DateTimeUTC, JsonB
+from advanced_alchemy.types import GUID, DateTimeUTC, FileObject, FileObjectList, JsonB, StoredObject
 from advanced_alchemy.utils.dataclass import DataclassProtocol
-from advanced_alchemy.utils.deprecation import warn_deprecation
 
 if TYPE_CHECKING:
     from sqlalchemy.sql import FromClause
     from sqlalchemy.sql.schema import (
         _NamingSchemaParameter as NamingSchemaParameter,  # pyright: ignore[reportPrivateUsage]
     )
-    from sqlalchemy.types import TypeEngine
-
-    # these should stay here since they are deprecated.  They are imported in the __getattr__ function
-    from advanced_alchemy.mixins import (
-        AuditColumns,
-        BigIntPrimaryKey,
-        NanoIDPrimaryKey,
-        SlugKey,
-        UUIDPrimaryKey,
-        UUIDv6PrimaryKey,
-        UUIDv7PrimaryKey,
-    )
 
 
 __all__ = (
     "AdvancedDeclarativeBase",
-    "AuditColumns",
     "BasicAttributes",
     "BigIntAuditBase",
     "BigIntBase",
     "BigIntBaseT",
-    "BigIntPrimaryKey",
     "CommonTableAttributes",
+    "IdentityAuditBase",
+    "IdentityBase",
+    "IdentityBaseT",
     "ModelProtocol",
     "NanoIDAuditBase",
     "NanoIDBase",
     "NanoIDBaseT",
-    "NanoIDPrimaryKey",
     "SQLQuery",
-    "SlugKey",
     "TableArgsType",
     "UUIDAuditBase",
     "UUIDBase",
     "UUIDBaseT",
-    "UUIDPrimaryKey",
     "UUIDv6AuditBase",
     "UUIDv6Base",
     "UUIDv6BaseT",
-    "UUIDv6PrimaryKey",
     "UUIDv7AuditBase",
     "UUIDv7Base",
     "UUIDv7BaseT",
-    "UUIDv7PrimaryKey",
     "convention",
     "create_registry",
     "merge_table_arguments",
@@ -101,46 +77,12 @@ __all__ = (
 )
 
 
-def __getattr__(attr_name: str) -> object:
-    if attr_name == "__path__":
-        return __file__
-
-    _deprecated_attrs = {
-        "SlugKey",
-        "AuditColumns",
-        "NanoIDPrimaryKey",
-        "BigIntPrimaryKey",
-        "UUIDPrimaryKey",
-        "UUIDv6PrimaryKey",
-        "UUIDv7PrimaryKey",
-    }
-    if attr_name in _deprecated_attrs:
-        from advanced_alchemy import mixins
-
-        module = "advanced_alchemy.mixins"
-        value = globals()[attr_name] = getattr(mixins, attr_name)
-
-        warn_deprecation(
-            deprecated_name=f"advanced_alchemy.base.{attr_name}",
-            version="0.26.0",
-            kind="import",
-            removal_in="1.0.0",
-            info=f"importing {attr_name} from 'advanced_alchemy.base' is deprecated, please import it from '{module}' instead",
-        )
-
-        return value
-    if attr_name in set(__all__).difference(_deprecated_attrs):
-        value = globals()[attr_name] = locals()[attr_name]
-        return value
-
-    msg = f"module {__name__!r} has no attribute {attr_name!r}"
-    raise AttributeError(msg)
-
-
 UUIDBaseT = TypeVar("UUIDBaseT", bound="UUIDBase")
 """Type variable for :class:`UUIDBase`."""
 BigIntBaseT = TypeVar("BigIntBaseT", bound="BigIntBase")
 """Type variable for :class:`BigIntBase`."""
+IdentityBaseT = TypeVar("IdentityBaseT", bound="IdentityBase")
+"""Type variable for :class:`IdentityBase`."""
 UUIDv6BaseT = TypeVar("UUIDv6BaseT", bound="UUIDv6Base")
 """Type variable for :class:`UUIDv6Base`."""
 UUIDv7BaseT = TypeVar("UUIDv7BaseT", bound="UUIDv7Base")
@@ -148,7 +90,7 @@ UUIDv7BaseT = TypeVar("UUIDv7BaseT", bound="UUIDv7Base")
 NanoIDBaseT = TypeVar("NanoIDBaseT", bound="NanoIDBase")
 """Type variable for :class:`NanoIDBase`."""
 
-convention: NamingSchemaParameter = {
+convention: "NamingSchemaParameter" = {
     "ix": "ix_%(column_0_label)s",
     "uq": "uq_%(table_name)s_%(column_0_name)s",
     "ck": "ck_%(table_name)s_%(constraint_name)s",
@@ -156,11 +98,11 @@ convention: NamingSchemaParameter = {
     "pk": "pk_%(table_name)s",
 }
 """Templates for automated constraint name generation."""
-table_name_regexp = re.compile("((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))")
+table_name_regexp = re.compile(r"((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))")
 """Regular expression for table name"""
 
 
-def merge_table_arguments(cls: type[DeclarativeBase], table_args: TableArgsType | None = None) -> TableArgsType:
+def merge_table_arguments(cls: type[DeclarativeBase], table_args: Optional[TableArgsType] = None) -> TableArgsType:
     """Merge Table Arguments.
 
     This function helps merge table arguments when using mixins that include their own table args,
@@ -188,7 +130,7 @@ def merge_table_arguments(cls: type[DeclarativeBase], table_args: TableArgsType
                 else:
                     args.append(last_positional_arg)
             else:
-                kwargs.update(arg_to_merge)
+                kwargs.update(arg_to_merge)  # pyright: ignore
 
     if args:
         if kwargs:
@@ -212,7 +154,7 @@ class ModelProtocol(Protocol):
         __mapper__: Mapper[Any]
         __name__: str
 
-    def to_dict(self, exclude: set[str] | None = None) -> dict[str, Any]:
+    def to_dict(self, exclude: Optional[set[str]] = None) -> dict[str, Any]:
         """Convert model to dictionary.
 
         Returns:
@@ -235,7 +177,7 @@ class BasicAttributes:
         __table__: FromClause
         __mapper__: Mapper[Any]
 
-    def to_dict(self, exclude: set[str] | None = None) -> dict[str, Any]:
+    def to_dict(self, exclude: Optional[set[str]] = None) -> dict[str, Any]:
         """Convert model to dictionary.
 
         Returns:
@@ -264,13 +206,17 @@ class CommonTableAttributes(BasicAttributes):
 
         @declared_attr.directive
         def __tablename__(cls) -> str:
-            """Infer table name from class name."""
+            """Infer table name from class name.
+
+            Returns:
+                str: The inferred table name.
+            """
 
             return table_name_regexp.sub(r"_\1", cls.__name__).lower()
 
 
 def create_registry(
-    custom_annotation_map: dict[Any, type[TypeEngine[Any]] | TypeEngine[Any]] | None = None,
+    custom_annotation_map: Optional[dict[Any, Union[type[TypeEngine[Any]], TypeEngine[Any]]]] = None,
 ) -> SQLAlchemyRegistry:
     """Create a new SQLAlchemy registry.
 
@@ -283,13 +229,17 @@ def create_registry(
     import uuid as core_uuid
 
     meta = MetaData(naming_convention=convention)
-    type_annotation_map: dict[Any, type[TypeEngine[Any]] | TypeEngine[Any]] = {
+    type_annotation_map: dict[Any, Union[type[TypeEngine[Any]], TypeEngine[Any]]] = {
         UUID: GUID,
         core_uuid.UUID: GUID,
         datetime.datetime: DateTimeUTC,
         datetime.date: Date,
         dict: JsonB,
+        dict[str, Any]: JsonB,
+        dict[str, str]: JsonB,
         DataclassProtocol: JsonB,
+        FileObject: StoredObject,
+        FileObjectList: StoredObject,
     }
     with contextlib.suppress(ImportError):
         from pydantic import AnyHttpUrl, AnyUrl, EmailStr, IPvAnyAddress, IPvAnyInterface, IPvAnyNetwork, Json
@@ -327,32 +277,44 @@ class MetadataRegistry:
         set: Sets the metadata for a given bind key.
     """
 
-    _instance: MetadataRegistry | None = None
-    _registry: dict[str | None, MetaData] = {None: orm_registry.metadata}
+    _instance: Optional["MetadataRegistry"] = None
+    _registry: dict[Union[str, None], MetaData] = {None: orm_registry.metadata}
 
     def __new__(cls) -> Self:
         if cls._instance is None:
             cls._instance = super().__new__(cls)
-        return cast(Self, cls._instance)
+        return cast("Self", cls._instance)
 
-    def get(self, bind_key: str | None = None) -> MetaData:
-        """Get the metadata for the given bind key."""
+    def get(self, bind_key: Optional[str] = None) -> MetaData:
+        """Get the metadata for the given bind key.
+
+        Args:
+            bind_key (Optional[str]): The bind key for the metadata.
+
+        Returns:
+            :class:`sqlalchemy.MetaData`: The metadata for the given bind key.
+        """
         return self._registry.setdefault(bind_key, MetaData(naming_convention=convention))
 
-    def set(self, bind_key: str | None, metadata: MetaData) -> None:
-        """Set the metadata for the given bind key."""
+    def set(self, bind_key: Optional[str], metadata: MetaData) -> None:
+        """Set the metadata for the given bind key.
+
+        Args:
+            bind_key (Optional[str]): The bind key for the metadata.
+            metadata (:class:`sqlalchemy.MetaData`): The metadata to set.
+        """
         self._registry[bind_key] = metadata
 
-    def __iter__(self) -> Iterator[str | None]:
+    def __iter__(self) -> Iterator[Union[str, None]]:
         return iter(self._registry)
 
-    def __getitem__(self, bind_key: str | None) -> MetaData:
+    def __getitem__(self, bind_key: Union[str, None]) -> MetaData:
         return self._registry[bind_key]
 
-    def __setitem__(self, bind_key: str | None, metadata: MetaData) -> None:
+    def __setitem__(self, bind_key: Union[str, None], metadata: MetaData) -> None:
         self._registry[bind_key] = metadata
 
-    def __contains__(self, bind_key: str | None) -> bool:
+    def __contains__(self, bind_key: Union[str, None]) -> bool:
         return bind_key in self._registry
 
 
@@ -373,7 +335,7 @@ class AdvancedDeclarativeBase(DeclarativeBase):
     registry = orm_registry
     __abstract__ = True
     __metadata_registry__: MetadataRegistry = MetadataRegistry()
-    __bind_key__: Optional[str] = None  # noqa: UP007
+    __bind_key__: Optional[str] = None
 
     def __init_subclass__(cls, **kwargs: Any) -> None:
         bind_key = getattr(cls, "__bind_key__", None)
@@ -384,7 +346,7 @@ class AdvancedDeclarativeBase(DeclarativeBase):
         super().__init_subclass__(**kwargs)
 
 
-class UUIDBase(_UUIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDBase(UUIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models with UUID v4 primary keys.
 
     .. seealso::
@@ -397,7 +359,7 @@ class UUIDBase(_UUIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase,
     __abstract__ = True
 
 
-class UUIDAuditBase(CommonTableAttributes, _UUIDPrimaryKey, _AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDAuditBase(CommonTableAttributes, UUIDPrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for declarative models with UUID v4 primary keys and audit columns.
 
     .. seealso::
@@ -411,7 +373,7 @@ class UUIDAuditBase(CommonTableAttributes, _UUIDPrimaryKey, _AuditColumns, Advan
     __abstract__ = True
 
 
-class UUIDv6Base(_UUIDv6PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDv6Base(UUIDv6PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models with UUID v6 primary keys.
 
     .. seealso::
@@ -424,7 +386,7 @@ class UUIDv6Base(_UUIDv6PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBa
     __abstract__ = True
 
 
-class UUIDv6AuditBase(CommonTableAttributes, _UUIDv6PrimaryKey, _AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDv6AuditBase(CommonTableAttributes, UUIDv6PrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for declarative models with UUID v6 primary keys and audit columns.
 
     .. seealso::
@@ -438,7 +400,7 @@ class UUIDv6AuditBase(CommonTableAttributes, _UUIDv6PrimaryKey, _AuditColumns, A
     __abstract__ = True
 
 
-class UUIDv7Base(_UUIDv7PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDv7Base(UUIDv7PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models with UUID v7 primary keys.
 
     .. seealso::
@@ -451,7 +413,7 @@ class UUIDv7Base(_UUIDv7PrimaryKey, CommonTableAttributes, AdvancedDeclarativeBa
     __abstract__ = True
 
 
-class UUIDv7AuditBase(CommonTableAttributes, _UUIDv7PrimaryKey, _AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+class UUIDv7AuditBase(CommonTableAttributes, UUIDv7PrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for declarative models with UUID v7 primary keys and audit columns.
 
     .. seealso::
@@ -465,7 +427,7 @@ class UUIDv7AuditBase(CommonTableAttributes, _UUIDv7PrimaryKey, _AuditColumns, A
     __abstract__ = True
 
 
-class NanoIDBase(_NanoIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+class NanoIDBase(NanoIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models with Nano ID primary keys.
 
     .. seealso::
@@ -478,7 +440,7 @@ class NanoIDBase(_NanoIDPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBa
     __abstract__ = True
 
 
-class NanoIDAuditBase(CommonTableAttributes, _NanoIDPrimaryKey, _AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+class NanoIDAuditBase(CommonTableAttributes, NanoIDPrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for declarative models with Nano ID primary keys and audit columns.
 
     .. seealso::
@@ -492,7 +454,7 @@ class NanoIDAuditBase(CommonTableAttributes, _NanoIDPrimaryKey, _AuditColumns, A
     __abstract__ = True
 
 
-class BigIntBase(_BigIntPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+class BigIntBase(BigIntPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models with BigInt primary keys.
 
     .. seealso::
@@ -505,7 +467,7 @@ class BigIntBase(_BigIntPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBa
     __abstract__ = True
 
 
-class BigIntAuditBase(CommonTableAttributes, _BigIntPrimaryKey, _AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+class BigIntAuditBase(CommonTableAttributes, BigIntPrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for declarative models with BigInt primary keys and audit columns.
 
     .. seealso::
@@ -519,6 +481,39 @@ class BigIntAuditBase(CommonTableAttributes, _BigIntPrimaryKey, _AuditColumns, A
     __abstract__ = True
 
 
+class IdentityBase(IdentityPrimaryKey, CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
+    """Base for all SQLAlchemy declarative models with database IDENTITY primary keys.
+
+    This model uses the database native IDENTITY feature for generating primary keys
+    instead of using database sequences.
+
+    .. seealso::
+        :class:`advanced_alchemy.mixins.IdentityPrimaryKey`
+        :class:`CommonTableAttributes`
+        :class:`AdvancedDeclarativeBase`
+        :class:`AsyncAttrs`
+    """
+
+    __abstract__ = True
+
+
+class IdentityAuditBase(CommonTableAttributes, IdentityPrimaryKey, AuditColumns, AdvancedDeclarativeBase, AsyncAttrs):
+    """Base for declarative models with database IDENTITY primary keys and audit columns.
+
+    This model uses the database native IDENTITY feature for generating primary keys
+    instead of using database sequences.
+
+    .. seealso::
+        :class:`CommonTableAttributes`
+        :class:`advanced_alchemy.mixins.IdentityPrimaryKey`
+        :class:`advanced_alchemy.mixins.AuditColumns`
+        :class:`AdvancedDeclarativeBase`
+        :class:`AsyncAttrs`
+    """
+
+    __abstract__ = True
+
+
 class DefaultBase(CommonTableAttributes, AdvancedDeclarativeBase, AsyncAttrs):
     """Base for all SQLAlchemy declarative models.  No primary key is added.
 
