@@ -55,6 +55,9 @@ def _default_msgspec_deserializer(
         value: Value to coerce
         type_decoders: Optional sequence of type decoders
 
+    Raises:
+        TypeError: If the value cannot be coerced to the target type
+
     Returns:
         A ``msgspec``-supported type
     """
@@ -112,12 +115,72 @@ class ResultConverter:
     @overload
     def to_schema(
         self,
-        data: ModelOrRowMappingT,
+        data: "ModelOrRowMappingT",
+        *,
+        schema_type: None = None,
+    ) -> "ModelOrRowMappingT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "Union[ModelProtocol, RowMapping]",
+        *,
+        schema_type: "type[ModelDTOT]",
+    ) -> "ModelDTOT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "ModelOrRowMappingT",
+        total: "Optional[int]" = None,
+        *,
+        schema_type: None = None,
+    ) -> "ModelOrRowMappingT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "Union[ModelProtocol, RowMapping]",
+        total: "Optional[int]" = None,
+        *,
+        schema_type: "type[ModelDTOT]",
+    ) -> "ModelDTOT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "ModelOrRowMappingT",
         total: "Optional[int]" = None,
         filters: "Union[Sequence[Union[StatementFilter, ColumnElement[bool]]], Sequence[StatementFilter], None]" = None,
         *,
         schema_type: None = None,
-    ) -> ModelOrRowMappingT: ...
+    ) -> "ModelOrRowMappingT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "Union[ModelProtocol, RowMapping]",
+        total: "Optional[int]" = None,
+        filters: "Union[Sequence[Union[StatementFilter, ColumnElement[bool]]], Sequence[StatementFilter], None]" = None,
+        *,
+        schema_type: "type[ModelDTOT]",
+    ) -> "ModelDTOT": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "Sequence[ModelOrRowMappingT]",
+        *,
+        schema_type: None = None,
+    ) -> "OffsetPagination[ModelOrRowMappingT]": ...
+
+    @overload
+    def to_schema(
+        self,
+        data: "Union[Sequence[ModelProtocol], Sequence[RowMapping]]",
+        *,
+        schema_type: "type[ModelDTOT]",
+    ) -> "OffsetPagination[ModelDTOT]": ...
 
     @overload
     def to_schema(
@@ -127,17 +190,7 @@ class ResultConverter:
         filters: "Union[Sequence[Union[StatementFilter, ColumnElement[bool]]], Sequence[StatementFilter], None]" = None,
         *,
         schema_type: None = None,
-    ) -> OffsetPagination[ModelOrRowMappingT]: ...
-
-    @overload
-    def to_schema(
-        self,
-        data: "Union[ModelProtocol, RowMapping]",
-        total: "Optional[int]" = None,
-        filters: "Union[Sequence[Union[StatementFilter, ColumnElement[bool]]], Sequence[StatementFilter], None]" = None,
-        *,
-        schema_type: type[ModelDTOT],
-    ) -> ModelDTOT: ...
+    ) -> "OffsetPagination[ModelOrRowMappingT]": ...
 
     @overload
     def to_schema(
@@ -146,7 +199,7 @@ class ResultConverter:
         total: "Optional[int]" = None,
         filters: "Union[Sequence[Union[StatementFilter, ColumnElement[bool]]], Sequence[StatementFilter], None]" = None,
         *,
-        schema_type: type[ModelDTOT],
+        schema_type: "type[ModelDTOT]",
     ) -> "OffsetPagination[ModelDTOT]": ...
 
     def to_schema(
@@ -167,8 +220,12 @@ class ResultConverter:
             total: The total number of rows in the data.
             filters: :class:`~advanced_alchemy.filters.StatementFilter`| :class:`sqlalchemy.sql.expression.ColumnElement` Collection of route filters.
             schema_type: :class:`~advanced_alchemy.service.typing.ModelDTOT` Optional schema type to convert the data to
+
+        Raises:
+            AdvancedAlchemyError: If `schema_type` is not a valid Pydantic or Msgspec schema and both libraries are not installed.
+
         Returns:
-            - :class:`~advanced_alchemy.base.ModelProtocol` | :class:`sqlalchemy.orm.RowMapping` | :class:`~advanced_alchemy.service.pagination.OffsetPagination` | :class:`msgspec.Struct` | :class:`pydantic.BaseModel`
+            :class:`~advanced_alchemy.base.ModelProtocol` | :class:`sqlalchemy.orm.RowMapping` | :class:`~advanced_alchemy.service.pagination.OffsetPagination` | :class:`msgspec.Struct` | :class:`pydantic.BaseModel`
         """
         if filters is None:
             filters = []
@@ -223,7 +280,7 @@ class ResultConverter:
                     get_type_adapter(schema_type).validate_python(data, from_attributes=True),
                 )
             limit_offset = find_filter(LimitOffset, filters=filters)
-            total = total if total else len(data)
+            total = total or len(data)
             limit_offset = limit_offset if limit_offset is not None else LimitOffset(limit=len(data), offset=0)
             return OffsetPagination[ModelDTOT](
                 items=get_type_adapter(list[schema_type]).validate_python(data, from_attributes=True),  # type: ignore[valid-type] # pyright: ignore[reportUnknownArgumentType]
